@@ -3,8 +3,8 @@
   FILE: icalfilesetimpl.h
   CREATOR: eric 23 December 1999
   
-  $Id: icalclusterimpl.h,v 1.2 2003/10/21 18:28:20 ettore Exp $
-  $Locker:  $
+  $Id: icalclusterimpl.h 393 2003-10-21 18:28:34Z ettore $
+  $Locker$
     
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
