@@ -1,16 +1,16 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-groupwise-folder.h: class for an groupwise folder */
 
-/* 
+/*
  * Authors:
  *   Sivaiah Nallagatla <snallagatla@novell.com>
  *   parthasarathi susarla <sparthasarathi@novell.com>
- *  
+ *
  *
  * Copyright (C) 2004, Novell, Inc.
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -28,12 +28,6 @@
 #ifndef CAMEL_GROUPWISE_FOLDER_H
 #define CAMEL_GROUPWISE_FOLDER_H 1
 
-
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
-
 #include <camel/camel-offline-folder.h>
 #include <camel/camel-mime-message.h>
 #include <camel/camel-folder-summary.h>
@@ -51,6 +45,8 @@ extern "C" {
 #define CAMEL_GROUPWISE_FOLDER_CLASS(k) (CAMEL_CHECK_CLASS_CAST ((k), CAMEL_GROUPWISE_FOLDER_TYPE, CamelGroupwiseFolderClass))
 #define CAMEL_IS_GROUPWISE_FOLDER(o)    (CAMEL_CHECK_TYPE((o), CAMEL_GROUPWISE_FOLDER_TYPE))
 
+G_BEGIN_DECLS
+
 typedef struct  _CamelGroupwiseFolder CamelGroupwiseFolder;
 typedef struct  _CamelGroupwiseFolderClass CamelGroupwiseFolderClass;
 struct _CamelGroupwiseFolder {
@@ -73,8 +69,8 @@ struct _CamelGroupwiseFolder {
 struct _CamelGroupwiseFolderClass {
 	CamelOfflineFolderClass parent_class;
 
-	/* Virtual methods */	
-	
+	/* Virtual methods */
+
 } ;
 
 
@@ -86,8 +82,6 @@ CamelFolder * camel_gw_folder_new(CamelStore *store, const char *folder_dir, con
 void gw_update_summary ( CamelFolder *folder, GList *item_list,CamelException *ex) ;
 void groupwise_refresh_folder(CamelFolder *folder, CamelException *ex);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* CAMEL_GROUPWISE_FOLDER_H */
